<?php
/**
* Main page generator
* 
* This page generates all of the pages in the site.
* It takes care of authentication and all that stuff
* and then includes the actual page that the user
* requested
*
* @author Stewart Smith
*/

function magicQuotesRemove(&$array) {
   if(!get_magic_quotes_gpc())
       return;
   foreach($array as $key => $elem) {
       if(is_array($elem))
           magicQuotesRemove($elem);
       else
           $array[$key] = stripslashes($elem);
   }
}

magicQuotesRemove($_GET);
magicQuotesRemove($_POST);
magicQuotesRemove($_COOKIE);

/**
 * Include site configuration
 *
 * @see config.inc
 */
include 'config.inc';

/**
 * List of pages, categories and associated permissions
 *
 * @see pages.inc
 */
include 'pages.inc';

/**
* Database access functions
*
* @see database
*/
require_once 'backend/database.inc';

/**
* Include Authentication code
*
* @see authentication.inc
*/
include 'backend/authentication.inc';

/**
 * Include Forms Code
 *
 * @see backend/forms.inc
 */
include 'backend/forms.inc';

/**
* Syslog functionality
*
* @see syslog
*/
// include 'backend/syslog.inc.php';

// Start the session
session_start();

$logged_in = login($_SESSION['user'],$_SESSION['password']);

if($_SESSION['user'] && $_SESSION['password'] && !$logged_in)
  my_syslog(LOG_ERR,"User not logged in");
     
if($_GET['page']=='confirm_membership')
     $_POST['function']='confirm_membership';

switch($_POST['function']) {
 case 'main':
   $_SESSION['user'] = $_POST['user'];
   $_SESSION['password'] = $_POST['password'];

   $logged_in = login($_SESSION['user'],$_SESSION['password']);

   if(!$logged_in) {
     unset( $_SESSION['user']);
     unset($_SESSION['password']);
   }

   break;
   
 case 'logout':
   $logged_in = 0;
   unset( $_SESSION['user']);
   unset($_SESSION['password']);
   break;
   
 case 'confirm_membership':
   include 'backend/functions/confirm_membership.inc';
   break;

 case 'signup_validate':
   /*
    * we validate stuff in the 'signup' function code
    * and this, the 'signup_validate' function only 
    * validates user input (before they say "yay")
    */
   break;

 case 'signup':
   include 'backend/functions/signup.inc';
   break;

 case 'approve_members':
   include 'backend/functions/approve_members.inc';
   break;

 case 'passwd':
   include 'backend/functions/passwd.inc';
   break;

 case 'add-position-type':
   include 'backend/functions/add-position-type.inc';
   break;

 case '':
   break;
 default:
   echo 'Unknown Function! '.$_POST['function'];
   my_syslog(LOG_WARNING,"Unknown function submitted - ".$_POST['function']);
   break;
}

/* if after performing the function we still don't have a page
   to view, then we set one - the default index page
*/
if(!$page)
{
  $page = $HTTP_GET_VARS['page'];
  if($page=='') $page = 'index';
}

if(!eregi("^[[:alpha:][:digit:]\_-]+$",$page))
{
  $page= 'index';
  my_syslog(LOG_WARNING,"Invalid page requested: $page");
}

/*
 * We have different include behaviour for the pages based
 * on if the user is logged in.
 *
 * We have two 'modes' for these things:
 *    - logged in
 *    - not logged in
 *
 * If a user is logged in, functions can also be based on
 * specific permissions, but this is taken care of by
 * individual pages (i.e. they must get it right).
 *
 */
if($logged_in)
{
  if(is_file('authenticated/'.$page.'.inc'))
    {
      // we're logged in, and authenticated page exists... so...
      $page_inc = 'authenticated/'.$page.".inc";
    }
  else
    {
      if(is_file('unauthenticated/'.$page.'.inc'))
	{
	  // try the unauthenticated page, as there isn't an auth version
	  $page_inc = 'unauthenticated/'.$page.'.inc';
	}
      else
	{
	  // the file doesn't exist, and we're authenticated
	  my_syslog(LOG_WARNING,"Unknown page passed while auth, defaulting to index: $page");
	  $page = 'index';
	  $page_inc = 'unauthenticated/'.$page.'.inc';
	}
    }
}
else
{
  if(is_file('unauthenticated/'.$page.'.inc'))
    {
      // we're not authenticated, and not logged in, but the page exists.
      $page_inc = 'unauthenticated/'.$page.'.inc';
    }
  else
    {
      if(is_file($page.'.inc'))
	{
	  // The inc file is in the current dir
	  $page_inc = $page.'.inc';
	}
      else
	{
	  // default back to index
	  my_syslog(LOG_WARNING,"Unknown page passed while unauth, defaulting to index: $page");
	  $page = 'index';
	  $page_inc = 'unauthenticated/index.inc';
	}
    }
}

function headers($param)
{
  global $permissions_pages, $page_param,$logged_in;
  
  $page_param = $param;

  header("Content-Type: text/html; charset=utf-8");
  header("X-Pants: off");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
 <head>
  <title><?=$param['title']?></title>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <link rel="stylesheet" type="text/css" href="global.css" />
 </head>
<body>
<div class="heading">
<h1><?=$param['title']?></h1>
</div>

<div class="container">
<?php
   if(!$param['menu']) {
     ?>
     <div class="mini-login">
     <p>You are logged in as <?=$_SESSION['user']?></p>
     </div>
     <div class="menulist">
     <ul class="menulist">
     <li><a href="?page=index">Home</a></li>
     </ul>
     </div>
     <?php
     } else {
     echo '<div class="menu">';
     
     $list = array();
     foreach ($permissions_pages as $page) {  
       if(!$page['activity']
	  || has_permission(get_member_id($_SESSION['user']),
			    $page['activity'])) {

	 if(!$page['logged_in'] || ($logged_in && $page['logged_in']))
	   array_push($list,
		    '<li><a href="?page='.
		    $page['page'].'">'.
		    $page['title'].'</a></li>');
       }
     }

     if($list) {
       print '<ul class="menu">';
       foreach($list as $i) { print $i;}
       print '</ul>';
     }
     echo '</div>';
   }

if($page_param['menu']) {

  echo '<div class="login">';

  if($logged_in==0)
    {
  ?>
 <h2>Login</h2>
    <form name="main" method="POST" action="<?=$PHP_SELF?>">
    <input type="hidden" name="function" value="main"/>
    <p class="field">
    <label for="user">Email Address:</label>
		       <input type="text" id="user" name="user"/>
		       </p>
    <p class="field">
    <label for="password">Password:</label>
    <input type="password" id="password" name="password"/></p>
    <input type="submit" name="submit" value="Login"/>
    </form>
  <?php
    } else {
  ?>
 <p>You are logged in as <?=$_SESSION['user']?></p>
    <form name="main" method="POST" action="<?=$PHP_SELF?>">
    <input type="hidden" name="function" value="logout"/>
    <input type="submit" value="Logout"/>
    </form>
    <?php
    }
      ?>
      </div>
      </div>
<?php
	  }
 if(!$param['menu'])
   echo '<div class="bodyformini">';
 else
   echo '<div class="body">';
}
include $page_inc;
?>
</div>

<div class="copyright">
<hr/>
<?php include $config['basedir'].'/site-look/footer.inc'; ?>
<p>This site is running <a href="http://www.flamingspork.com/projects/memberdb/">MemberDB</a> &copy;2002-2004 Stewart Smith.</p>
</div>
</body>
</html>
