<?php
/*
 * Signup Logic
 * ------------
 *
 * Rework of signup to use new forms infrastructure
 *
 * (C) 2003-2004 Stewart Smith
 * Distributed under the GPL.
 */


$title = "Linux Australia Membership Signup";
headers(array('title'=>$title,'menu'=>1));

$fields = array(
  'first_name'=> array('label'   =>'First Name',
		       'type'    =>'text',
		       'required'=>1,
		       'valid'   => array(
					  'preg_match("/\w+/", $val)'
					  =>'Must enter a first name'
					  ),
		       ),
  'middle_name'=>array('label'   =>'Middle Name/Initial',
		       'type'    =>'text',
		       ),
  'last_name'  =>array('label'   =>'Last Name',
		       'type'    =>'text',
		       ),
  'sex'        =>array('label'   =>'Sex',
		       'type'    =>'select',
		       'options' =>array('Male','Female'),
		       ),
  'address1'   =>array('label'   =>'Address 1',
		       'type'    =>'text',
		       'required'=> true,
		       'valid'   => array(
					  'preg_match("/\w{2,}/", $val)' =>
					  'Your address must contain at '.
					  'least two letters.',
					  ),
		       ),
  'address2'   =>array('label'   =>'Address 2',
		       'type'    =>'text',
		       ),
  'suburb'     =>array('label'   =>'Suburb',
		       'type'    =>'text',
		       'required'=>true,
		       'valid'   => array(
					  'preg_match("/\w+/", $val)'
					  =>'Must enter a suburb'
					  ),
		       ),
  'postcode'   =>array('label'   =>'Postcode',
		       'type'    =>'text',
		       'required'=>true,
		       'valid'   => array(
					  'preg_match("/\w+/", $val)'
					  =>'Must enter a postcode'
					  ),
		       ),
  'state'      =>array('label'   =>'State',
		       'type'    =>'text',
		       ),
  'country'    =>array('label'   =>'Country',
		       'type'    =>'text',
		       'required'=>true,
		       'valid'   =>array(
					 'preg_match("/\w+/", $val)'
					 =>'Must enter a country'
					 ),
		       ),
  'email'      =>array('label'   =>'Email Address',
		       'type'    =>'text',
		       'required'=>true,
		       'valid'   =>array(
					 'preg_match("/\w+/", $val)'
					 =>'Must enter an email address'
					 ),
		       ),
  'phone_home' =>array('label'   =>'Home Phone',
		       'type'    =>'text',
		       ),
  'phone_mobile'=>array('label'  =>'Mobile Phone',
			'type'   =>'text',
			),
  );

echo '<div class="stdform">';

include $config['basedir'].'/site-look/signup/responsibilities.inc';

echo '<h2>Details</h2>';

$errors = validate($fields, $HTTP_POST_VARS);

if(!$errors and strtolower($_SERVER['REQUEST_METHOD']) == 'post') {
  /*
   * FIXME: This should be one transaction. Crashing halfway isn't that
   * bad, we're just left with records in members which aren't a member
   * of anything.
   */
  $id = $dbh->nextId('public.members_id_seq');

  if($_POST['Sex']=='Male')
    $sexval = 'M';
  else if ($_POST['Sex']=='Female')
    $sexval = 'F';
  else
    $sexval = ' ';

  sql_insert('members',array(
			     'id'          => $id,
			     'first_name'  => $_POST['first_name'],
			     'middle_name' => $_POST['middle_name'],
			     'last_name'   => $_POST['last_name'],
			     'dob'         => $_POST['dob'],
			     'sex'         => $sexval,
			     'address1'    => $_POST['address1'],
			     'address2'    => $_POST['address2'],
			     'suburb'      => $_POST['suburb'],
			     'postcode'    => $_POST['postcode'],
			     'state'       => $_POST['state'],
			     'country'     => $_POST['country'],
			     'email'       => $_POST['email'],
			     'phone_home'  => $_POST['phone_home'],
			     'phone_mobile'=> $_POST['phone_mobile']));

  /* We don't need to quote anything
     in this query as it's all valid anyway (from the DB or subselect).
       
     This basically stores that the member (created above) is applying for
     membership to our organisation (as set in the config). The 'Pending'
     type of membership lasts for a year. Although it could be different...
  */
  $sql = 'insert into org_members (org_id,member_id,member_type_id,start_date,expiry) values ('.$config['org_id'].','.$id.",(select id from member_types where type='Applied'),now(),now()+'1year')";
  my_syslog(LOG_DEBUG,$sql);
  $result = $dbh->query($sql);
  if (DB::isError($result)) {
    my_syslog(LOG_INFO,$result->getMessage());
  }
  //include $config['basedir'].'/site-messages/signup/application-request-for-confirm.inc';

  print '<p>You submitted the following information:</p>'.
    '<ul>'.
    '<li><b>First Name: </b>'.$_POST['first_name'].'</li>'.
    '<li><b>Middle Name/Initial: </b>'.$_POST['middle_name'].'</li>'.
    '<li><b>Surname: </b>'.$_POST['last_name'].'</li>'.
    '<li><b>Sex: </b>'.$_POST['Sex'].'</li>'.
    '<li><b>Address 1: </b>'.$_POST['address1'].'</li>'.
    '<li><b>Address 2: </b>'.$_POST['address2'].'</li>'.
    '<li><b>Suburb: </b>'.$_POST['suburb'].'</li>'.
    '<li><b>Postcode: </b>'.$_POST['postcode'].'</li>'.
    '<li><b>State: </b>'.$_POST['state'].'</li>'.
    '<li><b>Country: </b>'.$_POST['country'].'</li>'.
    '<li><b>Email Address: </b>'.$_POST['email'].'</li>'.
    '<li><b>Home Phone: </b>'.$_POST['phone_home'].'</li>'.
    '<li><b>Mobile Phone: </b>'.$_POST['phone_mobile'].'</li>'.
    '</ul>';

  print '<p>You will shortly receive an email confirming your application for membership. Your membership will become active once confirmed by the secretary and you shall receive email notification of this.</p>';

} else {
print $errors;
output_form($fields);
}
echo '</div>';


?>
